| KorAPQuery-class | R Documentation |
Internal class for query state management. Users work with corpusQuery(), fetchAll(), and fetchNext() instead.
buildWebUIRequestUrlFromString(KorAPUrl, query, vc = "", ql = "poliqarp")
buildWebUIRequestUrl(
kco,
query = if (missing(KorAPUrl)) {
stop("At least one of the parameters query and KorAPUrl must be specified.", call. =
FALSE)
} else {
httr2::url_parse(KorAPUrl)$query$q
},
vc = if (missing(KorAPUrl)) "" else httr2::url_parse(KorAPUrl)$query$cq,
KorAPUrl,
ql = if (missing(KorAPUrl)) "poliqarp" else httr2::url_parse(KorAPUrl)$query$ql
)
## S3 method for class 'KorAPQuery'
format(x, ...)
## S4 method for signature 'KorAPQuery'
show(object)
x |
KorAPQuery object |
... |
further arguments passed to or from other methods |
object |
KorAPQuery object |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.