calculate_eta: Calculate and format ETA for batch operations

View source: R/logging.R

calculate_etaR Documentation

Calculate and format ETA for batch operations

Description

Helper function to calculate estimated time of arrival based on elapsed time and progress through a batch operation.

Usage

calculate_eta(current_item, total_items, start_time)

Arguments

current_item

current item number (1-based)

total_items

total number of items to process

start_time

POSIXct start time of the operation

Value

character string with formatted ETA and completion time or empty string if not calculable


RKorAPClient documentation built on Sept. 9, 2026, 5:11 p.m.