| fetchAll,KorAPQuery-method | R Documentation |
fetchAll fetches all results of a KorAP query.
## S4 method for signature 'KorAPQuery'
fetchAll(kqo, verbose = kqo@korapConnection@verbose, ...)
kqo |
object obtained from |
verbose |
print progress information if true |
... |
further arguments passed to |
The updated kqo object with all results in â @collectedMatchesâ
Other corpus search functions:
corpusQuery,KorAPConnection-method,
fetchAnnotations,KorAPQuery-method,
fetchNext,KorAPQuery-method
## Not run:
# Fetch all metadata of every query hit for "Ameisenplage" and show a summary
q <- KorAPConnection() |>
corpusQuery("Ameisenplage") |>
fetchAll()
q@collectedMatches
# Fetch also all KWICs
q <- KorAPConnection() |> auth() |>
corpusQuery("Ameisenplage", metadataOnly = FALSE) |>
fetchAll()
q@collectedMatches
# Retrieve title and text sigle metadata of all texts published on 1958-03-12
q <- KorAPConnection() |>
corpusQuery("<base/s=t>", # this matches each text once
vc = "pubDate in 1958-03-12",
fields = c("textSigle", "title"),
) |>
fetchAll()
q@collectedMatches
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.