| fetchNext,KorAPQuery-method | R Documentation |
fetchNext fetches the next bunch of results of a KorAP query.
## S4 method for signature 'KorAPQuery'
fetchNext(
kqo,
offset = kqo@nextStartIndex,
maxFetch = maxResultsPerPage,
verbose = kqo@korapConnection@verbose,
randomizePageOrder = FALSE
)
kqo |
object obtained from |
offset |
start offset for query results to fetch |
maxFetch |
maximum number of query results to fetch |
verbose |
print progress information if true |
randomizePageOrder |
fetch result pages in pseudo random order if true. Use |
The kqo input object with updated slots collectedMatches, apiResponse, nextStartIndex, hasMoreMatches
https://ids-pub.bsz-bw.de/frontdoor/index/index/docId/9026
Other corpus search functions:
corpusQuery,KorAPConnection-method,
fetchAll,KorAPQuery-method,
fetchAnnotations,KorAPQuery-method
## Not run:
q <- KorAPConnection() |>
corpusQuery("Ameisenplage") |>
fetchNext()
q@collectedMatches
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.