| initialize,KorAPQuery-method | R Documentation |
Initialize KorAPQuery object
## S4 method for signature 'KorAPQuery'
initialize(
.Object,
korapConnection = NULL,
request = NULL,
vc = "",
totalResults = 0,
nextStartIndex = 0,
fields = c("corpusSigle", "textSigle", "pubDate", "pubPlace", "availability",
"textClass", "snippet", "tokens"),
requestUrl = "",
webUIRequestUrl = "",
apiResponse = NULL,
hasMoreMatches = FALSE,
collectedMatches = NULL
)
.Object |
… |
korapConnection |
KorAPConnection object |
request |
query part of the request URL |
vc |
definition of a virtual corpus |
totalResults |
number of hits the query has yielded |
nextStartIndex |
at what index to start the next fetch of query results |
fields |
what data / metadata fields should be collected |
requestUrl |
complete URL of the API request |
webUIRequestUrl |
URL of a web frontend request corresponding to the API request |
apiResponse |
data-frame representation of the JSON response of the API request |
hasMoreMatches |
logical that signals if more query results can be fetched |
collectedMatches |
matches already fetched from the KorAP-API-server |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.