| log_info | R Documentation |
This module provides centralized logging functions used throughout the package for progress reporting and ETA calculations. Log informational messages with optional coloring
log_info(v, ...)
v |
logical flag indicating whether to output the message |
... |
message components to concatenate and display |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.