| textMetadata,KorAPConnection-method | R Documentation |
Retrieves metadata for a text, identified by its sigle (id) using the corresponding KorAP API
(see Kustvakt Wiki).
To retrieve the metadata for every text in a virtual corpus, use corpusQuery()
with <base/s=t> as query, instead.
## S4 method for signature 'KorAPConnection'
textMetadata(kco, textSigle, verbose = kco@verbose, cacheAs = NULL)
kco |
|
textSigle |
unique text id (concatenation of corpus, document and text ids, separated by |
verbose |
logical. If |
cacheAs |
path to an RDS file to keep the result in. If the file exists and records the same call, it is read back instead of contacting the server; otherwise the query is run and its result stored there. Unlike the connection's |
Tibble with columns for each metadata property. In case of errors, such as non-existing texts/sigles, the tibble will also contain a column called errors.
If there are metadata columns you cannot make sense of, please ignore them. The function simply returns all the metadata it gets from the server.
## Not run:
KorAPConnection() |> textMetadata(c("WUD17/A97/08542", "WUD17/B96/57558", "WUD17/A97/08541"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.