| calculate_eta | R Documentation |
Helper function to calculate estimated time of arrival based on elapsed time and progress through a batch operation.
calculate_eta(current_item, total_items, start_time)
current_item |
current item number (1-based) |
total_items |
total number of items to process |
start_time |
POSIXct start time of the operation |
character string with formatted ETA and completion time or empty string if not calculable
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.